@@ -569,10 +569,12 @@ EAction.prototype.hideOptionsToolBarWidgets = function(widgets, noSyncWidgets) {
 };
 
 /**
- * Called when user presses enter. Default implementation calls showDialog.
+ * Called when user presses enter. Default implementation calls showDialog if configured.
  */
 EAction.prototype.enterEvent = function() {
-    this.showDialog();
+    if (RSettings.getBoolValue("Transform/EnterShowsDialog", false)===true) {
+        this.showDialog();
+    }
 };
 
 /**
@@ -606,7 +608,12 @@ EAction.prototype.showDialog = function() {
     this.dialog = WidgetFactory.createDialog(this.includeBasePath, this.dialogUiFile, EAction.getMainWindow());
     this.initUiOptions(false, this.dialog);
     WidgetFactory.restoreState(this.dialog, this.settingsGroup, this);
-    this.dialog.windowTitle = this.getToolTitle();
+    var title = this.getToolTitle();
+    if (title.indexOf("\t")!==-1) {
+        // remove shortcuts Windows:
+        title = title.replace(/\t.*/g, "");
+    }
+    this.dialog.windowTitle = title;
     this.dialog.windowIcon = new QIcon();
 
     // give focus to control with custom property 'DefaultFocus':
